@@ -1,6 +1,6 @@
 from .enums import Color, Icon, Precision, Keyboard, TextAlignment, SliderBarType, DialNumberPosition, DialStyle,\
     SoundName, GraphLineType, TimeGraphLineType, TimeGraphPositionOfKey, ButtonState, LabelStyle, KnobStyle,\
-    TitlePosition, GraphXAxisLabelsStyle, TextFormat
+    TitlePosition, GraphXAxisLabelsStyle, TextFormat, DirectionStyle
 from .graph import Graph, GraphLine
 from .slider_single_bar import SliderSingleBar
 from .slider_double_bar import SliderDoubleBar
@@ -15,7 +15,7 @@ from .alarm import Alarm
 from .menu import Menu
 from .selector import Selector
 from .label import Label
-from .controls_box import ControlsBox
+from .device_view import DeviceView
 from .control import Control, ControlPosition
 from .button_group import ButtonGroup
 from .event_log import EventLog, EventData
